@@ -9,18 +9,18 @@
 
 #include <QAction>
 
-#include <KStandardAction>
-#include <KSharedConfig>
 #include <KConfigGroup>
+#include <KSharedConfig>
+#include <KStandardAction>
 #include <QIcon>
 
 #include <QApplication>
 #include <QClipboard>
-#include <QSqlQueryModel>
-#include <QSqlError>
 #include <QFontDatabase>
-#include <QTabWidget>
+#include <QSqlError>
+#include <QSqlQueryModel>
 #include <QTabBar>
+#include <QTabWidget>
 
 DbConsole::DbConsole(QWidget *parent)
     : QWidget(parent)
@@ -29,8 +29,7 @@ DbConsole::DbConsole(QWidget *parent)
 
     mTabWidget = new QTabWidget(this);
     mTabWidget->tabBar()->setTabsClosable(true);
-    connect(mTabWidget->tabBar(), &QTabBar::tabCloseRequested,
-            mTabWidget, [this](int index) {
+    connect(mTabWidget->tabBar(), &QTabBar::tabCloseRequested, mTabWidget, [this](int index) {
         mTabWidget->removeTab(index);
         saveQueries();
     });
@@ -91,7 +90,7 @@ DbConsoleTab::DbConsoleTab(int index, QWidget *parent)
     ui.resultView->addAction(copyAction);
 
     ui.execButton->setIcon(QIcon::fromTheme(QStringLiteral("application-x-executable")));
-    ui.execButton->setShortcut(Qt::CTRL + Qt::Key_Return);
+    ui.execButton->setShortcut(Qt::CTRL | Qt::Key_Return);
     connect(ui.execButton, &QPushButton::clicked, this, &DbConsoleTab::execClicked);
 
     ui.queryEdit->setFont(QFontDatabase::systemFont(QFontDatabase::FixedFont));
