@@ -5,12 +5,14 @@
 */
 
 #include "debugfiltermodel.h"
-#include "debugmodel.h"
 #include "akonadiconsole_debug.h"
+#include "debugmodel.h"
 
 #include <KCheckComboBox>
 
+#ifndef COMPILE_WITH_UNITY_CMAKE_SUPPORT
 Q_DECLARE_METATYPE(DebugModel::Message)
+#endif
 
 using namespace KPIM;
 
@@ -19,8 +21,7 @@ DebugFilterModel::DebugFilterModel(QObject *parent)
 {
     mInvalidateTimer.setInterval(50);
     mInvalidateTimer.setSingleShot(true);
-    connect(&mInvalidateTimer, &QTimer::timeout,
-            this, &DebugFilterModel::invalidate);
+    connect(&mInvalidateTimer, &QTimer::timeout, this, &DebugFilterModel::invalidate);
 }
 
 DebugFilterModel::~DebugFilterModel()
@@ -33,9 +34,8 @@ void DebugFilterModel::setSenderFilter(KCheckComboBox *senderFilter)
         mSenderFilter->disconnect(this);
     }
     mSenderFilter = senderFilter;
-    connect(mSenderFilter, &KCheckComboBox::checkedItemsChanged,
-            this, [this](const QStringList &_items) {
-        Q_UNUSED(_items);
+    connect(mSenderFilter, &KCheckComboBox::checkedItemsChanged, this, [this](const QStringList &_items) {
+        Q_UNUSED(_items)
         const auto items = mSenderFilter->checkedItems(DebugModel::IdentifierRole);
         mCheckedSenders.clear();
         mCheckedSenders.reserve(items.count());
