@@ -5,12 +5,13 @@
 */
 
 #include "loggingfiltermodel.h"
-#include "loggingmodel.h"
 #include "akonadiconsole_debug.h"
+#include "loggingmodel.h"
 
 #include <KCheckComboBox>
-
+#ifndef COMPILE_WITH_UNITY_CMAKE_SUPPORT
 Q_DECLARE_METATYPE(LoggingModel::Message)
+#endif
 
 using namespace KPIM;
 
@@ -19,8 +20,7 @@ LoggingFilterModel::LoggingFilterModel(QObject *parent)
 {
     mInvalidateTimer.setInterval(50);
     mInvalidateTimer.setSingleShot(true);
-    connect(&mInvalidateTimer, &QTimer::timeout,
-            this, &LoggingFilterModel::invalidate);
+    connect(&mInvalidateTimer, &QTimer::timeout, this, &LoggingFilterModel::invalidate);
 }
 
 LoggingFilterModel::~LoggingFilterModel()
@@ -33,8 +33,7 @@ void LoggingFilterModel::setAppFilter(KCheckComboBox *appFilter)
         mAppFilter->disconnect(this);
     }
     mAppFilter = appFilter;
-    connect(mAppFilter, &KCheckComboBox::checkedItemsChanged,
-            this, [this](const QStringList &items) {
+    connect(mAppFilter, &KCheckComboBox::checkedItemsChanged, this, [this](const QStringList &items) {
         mCheckedApps.clear();
         mCheckedApps.reserve(items.count());
         for (const auto &item : items) {
@@ -52,8 +51,7 @@ void LoggingFilterModel::setTypeFilter(KCheckComboBox *typeFilter)
         mTypeFilter->disconnect(this);
     }
     mTypeFilter = typeFilter;
-    connect(mTypeFilter, &KCheckComboBox::checkedItemsChanged,
-            this, [this](const QStringList &items) {
+    connect(mTypeFilter, &KCheckComboBox::checkedItemsChanged, this, [this](const QStringList &items) {
         mCheckedTypes.clear();
         mCheckedTypes.reserve(items.count());
         for (const auto &item : mTypeFilter->checkedItems(Qt::UserRole)) {
@@ -71,8 +69,7 @@ void LoggingFilterModel::setCategoryFilter(KCheckComboBox *categoryFilter)
         mCategoryFilter->disconnect(this);
     }
     mCategoryFilter = categoryFilter;
-    connect(mCategoryFilter, &KCheckComboBox::checkedItemsChanged,
-            this, [this](const QStringList &items) {
+    connect(mCategoryFilter, &KCheckComboBox::checkedItemsChanged, this, [this](const QStringList &items) {
         mCheckedCategories.clear();
         mCheckedCategories.reserve(items.count());
         for (const auto &item : items) {
@@ -88,7 +85,5 @@ bool LoggingFilterModel::filterAcceptsRow(int source_row, const QModelIndex &) c
 {
     const auto source_idx = sourceModel()->index(source_row, 0);
     const auto msg = sourceModel()->data(source_idx, LoggingModel::MessageRole).value<LoggingModel::Message>();
-    return mCheckedApps.contains(msg.app)
-           && mCheckedCategories.contains(msg.category)
-           && mCheckedTypes.contains(msg.type);
+    return mCheckedApps.contains(msg.app) && mCheckedCategories.contains(msg.category) && mCheckedTypes.contains(msg.type);
 }
