@@ -10,7 +10,8 @@
 class QWidget;
 class KConfigGroup;
 
-namespace AkonadiConsole {
+namespace AkonadiConsole
+{
 /**
  * @short Methods to save and restore the UI state of an application.
  *
@@ -29,19 +30,20 @@ namespace AkonadiConsole {
  * @author Volker Krause <vkrause@kde.org>
  * @since 4.5
  */
-namespace UiStateSaver {
+namespace UiStateSaver
+{
 /**
-   * Saves the state of @p widget and all its sub-widgets to @p config.
-   * @param widget The top-level widget which state should be saved.
-   * @param config The config group the settings should be written to.
-   */
+ * Saves the state of @p widget and all its sub-widgets to @p config.
+ * @param widget The top-level widget which state should be saved.
+ * @param config The config group the settings should be written to.
+ */
 void saveState(QWidget *widget, KConfigGroup &config);
 
 /**
-   * Restores the UI state of @p widget and all its sub-widgets from @p config.
-   * @param widget The top-level widget which state should be restored.
-   * @param config The config gorup the settings should be read from.
-   */
+ * Restores the UI state of @p widget and all its sub-widgets from @p config.
+ * @param widget The top-level widget which state should be restored.
+ * @param config The config gorup the settings should be read from.
+ */
 void restoreState(QWidget *widget, const KConfigGroup &config);
 }
 }
